@@ -19,8 +19,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <errno.h>
 
+#include "errno.hpp"
 #include "fileinfo.hpp"
 
 static
