@@ -17,8 +17,8 @@
 #include <fuse.h>
 
 #include <unistd.h>
-#include <errno.h>
 
+#include "errno.hpp"
 #include "fileinfo.hpp"
 
 static
