@@ -17,12 +17,12 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <errno.h>
 
 #include <string>
 
-#include "fs_path.hpp"
+#include "errno.h"
 #include "fs_attr.hpp"
+#include "fs_path.hpp"
 #include "fs_xattr.hpp"
 
 using std::string;
