@@ -24,8 +24,8 @@
 #include <vector>
 
 #include <unistd.h>
-#include <errno.h>
 
+#include "errno.hpp"
 #include "fileinfo.hpp"
 
 static
