@@ -18,8 +18,8 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#include <errno.h>
 
+#include "errno.hpp"
 #include "fileinfo.hpp"
 
 static
