@@ -17,10 +17,10 @@
 #include <fuse.h>
 
 #include <unistd.h>
-#include <errno.h>
 
 #include <string>
 
+#include "errno.hpp"
 #include "fileinfo.hpp"
 
 static
